@@ -9,11 +9,13 @@ related tags (e.g. SP and PV) to plot on the same subplot.
 from .pp import add_grouping_rule, \
                 remove_grouping_rules, \
                 print_grouping_rules, \
+                load_grouping_template, \
                 set_dataframe, show
 
 __all__ = ['add_grouping_rule',
            'remove_grouping_rules',
            'print_grouping_rules',
+           'load_grouping_template',
            'set_dataframe',
            'show']
 
